import { parse } from 'graphql/language/parser';
import { print } from 'graphql/language/printer';
import React from 'react';
import { runParser } from './runParser';
export const GraphQLCodeBlock = ({ className = "GraphQLCodeBlock", src }) => {
    let formatted;
    try {
        formatted = print(parse(src));
    }
    catch (e) {
        // eslint-disable-next-line no-console
        console.error(e);
        return React.createElement("pre", { className: `${className} error` }, src);
    }
    const highlighted = [];
    const rowKeys = [];
    runParser(formatted, (stream, state, style, rowIndex, newRow) => {
        const { _sourceText, _start, _pos } = stream;
        if (newRow) {
            rowKeys.push(_sourceText);
            highlighted.push([]);
        }
        const substr = _sourceText.substring(_start, _pos);
        highlighted[highlighted.length - 1].push(React.createElement("span", { key: `${rowKeys.length}-${_start}-${_pos}`, className: style }, substr));
    });
    return (React.createElement("div", { className: className }, highlighted.map((row, index) => {
        return (React.createElement("pre", { key: `query-row-${index}` }, row));
    })));
};
//# sourceMappingURL=index.js.map